//HelpMenu.java - Part of Bill's Java Minesweeper
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class HelpMenu extends JMenu {
   MyMines parent;
   JMenuItem hHelpTopics, hAboutMinesweeper;

   HelpMenu(final MyMines parent) {
      super("Help");
      this.parent = parent;
      
      //Items on the Help menu.
      hHelpTopics = new JMenuItem("Help Topics");
      hHelpTopics.addActionListener(new Help());
      hAboutMinesweeper = new JMenuItem("About Minesweeper");
      hAboutMinesweeper.addActionListener(new About());

      add(hHelpTopics);
      addSeparator();
      add(hAboutMinesweeper);
   }

   class About implements ActionListener {
      String aboutString =
         "Bill's Java Minesweeper Applet.\n" +
         "Developed as a Java language learning project.\n" +
         "Version 0.95, July 2002.\n\n" +
         "http://billmarty1.home.attbi.com/java.htm\n\n" +
         "Thanks to Microsoft, Robert Donner, and Curt Johnson\n" +
         "for inspiration.";
      public void actionPerformed(ActionEvent e) {
         JOptionPane.showMessageDialog(parent.game, aboutString, "About Minesweeper",
                                        JOptionPane.PLAIN_MESSAGE);
      }
   }//End About.
   
   class Help implements ActionListener {
      JFrame helpFrame;
      Container helpPane;
      JTabbedPane helpTabs;
      JTextArea howTo, tips;
      
      String howToString = 
         " The object of Minesweeper is to mark all mines,\n" +
         " without detonating a mine.  Each cell in the Sea grid\n" +
         " potentially contains a mine.  To mark a cell that you\n" +
         " think contains a mine, right click the cell.  To reveal\n" +
         " the contents of a cell, left click.\n\n" +
         " If a revealed cell contains a number, the number tells\n" +
         " you how many mines are in the immediately adjacent cells.\n\n" +
         " The game board consists of a mine count, the smiley button\n" +
         " which starts a new game, the timer, and the Sea grid.\n" +
         " Start a new game by revealing any cell in the Sea grid.  The\n" +
         " timer will start.  To win, all cells must be marked as \n" +
         " containing a mine, or revealed.\n";
      
      String tipsString =
         " The key to Minesweeper is learning to recognize patterns\n" +
         " of numbers.  For instance, if all but one of the cells\n" +
         " surrounding a 1 have been revealed, then the remaining cell\n" +
         " must contain a mine.  As another example, 2-3-2 along the edge\n" +
         " of a region of unrevealed cells indicates three mines in a row.\n\n" +
         " Shortcut:  Once you have flagged all the mines around a numbered\n" +
         " cell, you can reveal all the remaining adjacent cells by clicking\n" +
         " both mouse buttons simultaneously on the numbered cell.\n";

      public void showHelp() {
         helpFrame = new JFrame("Minesweeper Help");
         helpFrame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
         helpFrame.setSize(400, 300);
         helpFrame.setResizable(false);
         helpFrame.setLocationRelativeTo(null);   //Center Help on screen.
         
         helpTabs = new JTabbedPane();
         howTo = new JTextArea(howToString);
         howTo.setEditable(false);
         tips = new JTextArea(tipsString);
         tips.setEditable(false);
         helpTabs.addTab("How to Play", howTo);
         helpTabs.addTab("Tips", tips);
         
         helpPane = helpFrame.getContentPane();
         helpPane.add(helpTabs);
         helpFrame.setVisible(true);
      }
      
      public void actionPerformed(ActionEvent e) {
         showHelp();
      }
      
   }//End Help.

}//End HelpMenu.
